@@ -5,12 +5,13 @@
 notify() {
     CATEGORY=$1
     MSG=$2
-    ICON_bluetooth=" "
-    ICON_super_hybrid_engine=" "
-    ICON_error=" "
-    ICON_camera=" "
-    ICON_touchpad=" "
-    ICON_gsm=" "
+    ICON_bluetooth="bluetooth"
+    ICON_super_hybrid_engine="battery"
+    ICON_error="error"
+    ICON_camera="camera"
+    ICON_touchpad="input-touchpad"
+    ICON_gsm="gsm"
+    ICON_wifi="network-wireless"
 
     if [ -n "$4" -o \( -n "$3" -a "$3" != 'fast' \) ]; then
 	echo "usage: notify 'category' 'message text' [fast]" > /dev/stderr
@@ -29,7 +30,11 @@ notify() {
     fi
 
     if [ -x /usr/bin/notify-send ]; then
-        notify-send -i $ICON_"$1" "$2"
+	getXconsole
+	eval home=~$user
+	eval `grep -m 1 ^DBUS_SESSION_BUS_ADDRESS $home/.dbus/session-bus/*`
+	eval ICON=\$ICON_$1
+	su $user -c notify-send\ -i\ $ICON\ "$2"
     else
         echo "Please install libnotify-bin" > /dev/stderr
         return 1
