@@ -1,6 +1,6 @@
 #!/bin/sh
 
-test -d /sys/bus/platform/devices/eeepc || exit 0
+[ -d /sys/devices/platform/eeepc ] || [ -d /sys/devices/platform/eeepc-wmi ] || exit 0
 # do nothing if package is removed
 PKG=eeepc-acpi-scripts
 PKG_DIR=/usr/share/acpi-support/$PKG
@@ -32,7 +32,7 @@ getvga_status(){
     esac
 }
 
-detect_x_display
+getXconsole
 getvga_status;
 # handle return value
 case $? in
